Module macrostate

Module macrostate 

Traits that describe system macrostates and types that implement them.

Macrostate

Use a built-in macrostate type, such as Isothermal, IsothermalIsobaric or Isobaric store the temperature and/or pressure set points for use with thermostats, barostats, and/or Monte Carlo trial moves:

use hoomd_simulation::macrostate::Isothermal;

let macrostate = Isothermal { temperature: 1.2 };

The actual ensemble that your simulation samples is set by the methods that you apply to it. These macrostate types exist merely to pass parameters to methods that need them. For example, you could choose an IsothermalIsobaric macrostate and use it only with local Monte Carlo moves. Without boundary moves, the simulation will be in the NVT ensemble.

Traits

When you need additional macrostate parameters, use a custom type. Implement Temperature and/or Pressure for your type as needed.

Structs

Isobaric
Constant pressure macrostate.
Isothermal
Constant temperature macrostate.
IsothermalIsobaric
Constant temperature, constant pressure macrostate.

Traits

Pressure
Set the thermodynamic pressure of a system.
Temperature
Set the thermodynamic temperature of a system.