pub trait Simulation {
// Required methods
fn advance(&mut self) -> Result<()>;
fn step(&self) -> u64;
}Expand description
Store parameters, the model and the microstate(s) it acts on.
A Simulation type stores the microstate, all model actors, and any
macrostate parameters in fields. A given Simulation can be advanced
forward one step at a time via the advance method.